@@ -957,7 +957,9 @@ setMethodS3("getMethods", "Class", function(this, private=FALSE, deprecated=TRUE
   positions <- seq(along=searchPaths);
   envirs <- as.environment(positions);
 
-  members <- lapply(envirs, function(env) .Internal(ls(env, private)) );
+  members <- lapply(envirs, function(env) {
+    ls(envir=env, all.names=private);
+  });
   members <- unlist(members);
 
   # First, remove all members that does not contain a . (period), because
@@ -1021,7 +1023,7 @@ setMethodS3("getMethods", "Class", function(this, private=FALSE, deprecated=TRUE
   result <- result[sapply(result, FUN=function(x) (length(x) > 0))];
 
   result;
-}) # getMethods()
+}, dontWarn="base") # getMethods()
 
 
 
@@ -1435,6 +1437,12 @@ setMethodS3("[[<-", "Class", function(this, name, value) {
 
 ############################################################################
 # HISTORY:
+# 2012-03-08
+# o Now package no longer warnings about renaming existing functions
+#   getMethods() and getClasses() of 'base' to default methods during
+#   installation, iff R.methodsS3 (>= 1.2.3).
+# 2012-02-29
+# o CLEANUP: Dropped an .Internal() call in getMethods() for Class objects.
 # 2011-02-01
 # o ROBUSTNESS: Now using 'inherits' (not 'inherit') in all calls to
 #   get() and exists().
